viewmask
========
A Python package and CLI to view XML annotations and NumPy masks.

|PyPI version fury.io|
|PyPI downloads|
|PyPI license|
|Documentation Status|

.. |PyPI version fury.io| image:: https://badge.fury.io/py/viewmask.svg
   :target: https://pypi.python.org/pypi/viewmask/
   
.. |PyPI downloads| image:: https://img.shields.io/pypi/dm/viewmask
   :target: https://pypistats.org/packages/viewmask

.. |PyPI license| image:: https://img.shields.io/pypi/l/viewmask.svg
   :target: https://pypi.python.org/pypi/viewmask/

.. |Documentation Status| image:: https://readthedocs.org/projects/viewmask/badge/?version=latest
   :target: https://viewmask.readthedocs.io/?badge=latest
   

